@@ -1061,6 +1061,10 @@ gboolean project_close(appdata_t *appdata) {
   if(appdata->osm)
     diff_save(appdata->project, appdata->osm);
 
+  /* Save track and turn off the handler callback */
+  track_save(appdata->project, appdata->track.track);
+  track_do(appdata, TRACK_NONE, NULL);
+
   map_clear(appdata, MAP_LAYER_ALL);
 
   if(appdata->osm) {
